@@ -1,8 +1,8 @@
-PageProcessing <- function(MyEOL) {
+PageProcessing <- function(MyEOL, ...) {
   if(class(MyEOL) == "character" || class(MyEOL) == "vector")
-    res <- xmlToList(xmlRoot(xmlParse(MyEOL, getDTD=FALSE)), simplify=FALSE)
+    res <- xmlToList(xmlRoot(xmlParse(MyEOL, getDTD=FALSE), ...), simplify=FALSE)
   if(class(MyEOL) == "list")
-    res <- xmlToList(xmlRoot(xmlParse(MyEOL[[1]], getDTD=FALSE)), simplify=FALSE)
+    res <- xmlToList(xmlRoot(xmlParse(MyEOL[[1]], getDTD=FALSE), ...), simplify=FALSE)
   if(is.na(GetHierID(MyEOL)))
     return(paste("Filenames contain NAs"))
   if(!is.null(res$error)){
